@@ -4,11 +4,23 @@
 #  include <config.h>
 #endif
 
+#include <gtk/gtk.h>
+#include <fitsio.h>	// fitsfile
+#include <gsl/gsl_histogram.h>
+#ifdef _OPENMP
+#include <omp.h>
+#endif
+#include <libintl.h>
+
 // PATH_MAX is not available on Hurd at least
 #ifndef PATH_MAX
 #define PATH_MAX 4096
 #endif
 
+#define _(String) gettext (String)
+#define gettext_noop(String) String
+#define N_(String) gettext_noop (String)
+
 #define max(a,b) \
    ({ __typeof__ (a) _a = (a); \
        __typeof__ (b) _b = (b); \
@@ -19,13 +31,6 @@
      _a < _b ? _a : _b; })
 #define SQR(x) ((x)*(x))
 
-#include <gtk/gtk.h>
-#include <fitsio.h>	// fitsfile
-#include <gsl/gsl_histogram.h>
-#ifdef _OPENMP
-#include <omp.h>
-#endif
-
 #define USHRT_MAX_DOUBLE ((double)USHRT_MAX)
 #define USHRT_MAX_SINGLE ((float)USHRT_MAX)
 #define UCHAR_MAX_DOUBLE ((double)UCHAR_MAX)
@@ -206,7 +211,7 @@ struct imdata {
  * Returns < 0 for an error that should stop the processing on the sequence.
  * Other return values are not used.
  * Processed data should be written in the sequence data directly. */
-typedef int (*sequence_proc)(sequence *seq, int seq_layer, int frame_no, fits *fit, rectangle *source_area);
+typedef int (*sequence_proc)(sequence *seq, int seq_layer, int frame_no, fits *fit, rectangle *source_area, void *arg);
 
 /* preprocessing data from GUI */
 struct preprocessing_data {
@@ -402,10 +407,12 @@ struct ffit {
 	char date_obs[FLEN_VALUE];		// YYYY-MM-DDThh:mm:ss observation start, UT
 	char date[FLEN_VALUE];		// YYYY-MM-DDThh:mm:ss creation of file, UT
 	char instrume[FLEN_VALUE];		// INSTRUME key
+	char telescop[FLEN_VALUE];		// TELESCOP key
+	char observer[FLEN_VALUE];		// OBSERVER key
 	/* data obtained from FITS or RAW files */
 	double focal_length, iso_speed, exposure, aperture, ccd_temp;
 
-	/* data used in the Fourrier space */
+	/* data used in the Fourier space */
 	double dft_norm[3];			// Normalization value
 	char dft_type[FLEN_VALUE];		// spectrum, phase
 	char dft_ord[FLEN_VALUE];		// regular, centered
@@ -488,7 +495,8 @@ struct cominf {
 	sliders_mode sliders;		// 0: min/max, 1: MIPS-LO/HI, 2: user
 	gboolean leveldrag;		// middle click being dragged if true
 	int preprostatus;
-	gboolean show_excluded;		// show excluded images in sequences NOT USED!
+	gboolean prepro_cfa;	// Use to save type of sensor for cosmetic correction in preprocessing
+	gboolean show_excluded;		// show excluded images in sequences
 	double zoom_value;		// 1.0 is normal zoom, use get_zoom_val() to access it
 
 	/* selection rectangle for registration, FWHM, PSF */
@@ -514,6 +522,8 @@ struct cominf {
 	
 	gboolean dontShowConfirm;
 
+	gboolean have_dark_theme;	// we have a dark theme, use bright colours
+
 	stackconf stack;
 	
 	int filter;
@@ -545,13 +555,13 @@ struct cominf {
 	fitted_PSF **stars;		// list of stars detected in the current image
 	gboolean star_is_seqdata;	// the only star in stars belongs to seq, don't free it
 	int selected_star;		// current selected star in the GtkListStore
-	double magOffset;		// offset to reduce the real magitude
+	double magOffset;		// offset to reduce the real magnitude
 	
 	gradient *grad;
 	int grad_nb_boxes, grad_size_boxes;
 	gboolean grad_boxes_drawn;
 
-	GThread *thread;		// the thread for processings
+	GThread *thread;		// the thread for processing
 	GMutex mutex;			// a mutex we use for this thread
 	gboolean run_thread;		// the main thread loop condition
 	int max_thread;			// maximum of thread used
