@@ -24,7 +24,7 @@
 #include <assert.h>
 #include <ctype.h>
 #include <string.h>
-#include <gsl/gsl_statistics_double.h>
+#include <gsl/gsl_statistics.h>
 
 #include "core/siril.h"
 #include "core/proto.h"
@@ -56,7 +56,7 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	long orig[3] = { 1L, 1L, 1L };
 	// orig ^ gives the coordinate in each dimension of the first pixel to be read
 	int zero = 0;
-	char name[256], *msg = NULL;
+	char name[256], *msg = NULL, *basename;
 	image_type imagetype;
 	int i;
 	unsigned int nbdata;
@@ -68,23 +68,23 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	fit->naxes[2] = 1; //initialization of the axis numer before opening : NEED TO BE OPTIMIZED
 
 	if (stat_file(filename, &imagetype, name)) {
-		msg = siril_log_message("%s.[any_allowed_extension] not found.\n",
+		msg = siril_log_message(_("%s.[any_allowed_extension] not found.\n"),
 				filename);
-		show_dialog(msg, "Error", "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		return 1;
 	}
 	if (imagetype != TYPEFITS) {
 		msg = siril_log_message(
-						"The file %s is not a FITS file or doesn't exists with FITS extensions.\n",
+				_("The file %s is not a FITS file or doesn't exists with FITS extensions.\n"),
 						filename);
-		show_dialog(msg, "Error", "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		return 1;
 	}
 
 	if (realname)
 		strcpy(realname, name);
 	status = 0;
-	fits_open_file(&(fit->fptr), name, READONLY, &status);
+	fits_open_diskfile(&(fit->fptr), name, READONLY, &status);
 	if (status) {
 		report_fits_error(status);
 		return status;
@@ -95,8 +95,8 @@ int readfits(const char *filename, fits *fit, char *realname) {
 			&status);
 	if (status) {
 		msg = siril_log_message(
-				"FITSIO error getting image parameters, file %s.\n", filename);
-		show_dialog(msg, "Error", "gtk-dialog-error");
+				_("FITSIO error getting image parameters, file %s.\n"), filename);
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		report_fits_error(status);
 		status = 0;
 		fits_close_file(fit->fptr, &status);
@@ -108,9 +108,9 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	nbdata = fit->rx * fit->ry;
 
 	if (fit->naxis == 3 && fit->naxes[2] != 3) {
-		msg = siril_log_message("Unknown FITS image format (%ld axes).\n",
+		msg = siril_log_message(_("Unknown FITS image format (%ld axes).\n"),
 				fit->naxes[2]);
-		show_dialog(msg, "Error", "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		status = 0;
 		fits_close_file(fit->fptr, &status);
 		return -1;
@@ -124,8 +124,8 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	}
 	if (fit->bitpix == LONGLONG_IMG) {
 		msg = siril_log_message(
-				"FITS images with 64 bits signed integer per pixel.channel are not supported.\n");
-		show_dialog(msg, "Error", "gtk-dialog-error");
+				_("FITS images with 64 bits signed integer per pixel.channel are not supported.\n"));
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		status = 0;
 		fits_close_file(fit->fptr, &status);
 		return -1;
@@ -183,10 +183,17 @@ int readfits(const char *filename, fits *fit, char *realname) {
 		status = 0;
 		fits_read_pix(fit->fptr, TLONG, orig, nbdata * fit->naxes[2], &zero,
 				pixels_long, &zero, &status);
+		long m_long = gsl_stats_long_max(pixels_long, 1, nbdata * fit->naxes[2]);
 		for (i = 0; i < nbdata * fit->naxes[2]; i++) {
 			double shift = (double) (0x80000000UL - offset) / (double) UINT_MAX;
-			double pixel = (double) (pixels_long[i] / (double) UINT_MAX);
-			fit->data[i] = round_to_WORD((pixel + shift) * USHRT_MAX_DOUBLE);
+			if (m_long> USHRT_MAX) {
+				double pixel = (double) (pixels_long[i] / (double) UINT_MAX);
+				fit->data[i] = round_to_WORD((pixel + shift) * USHRT_MAX_DOUBLE);
+			}
+			else {
+				double pixel = (double) (pixels_long[i]);
+				fit->data[i] = round_to_WORD((pixel + shift));
+			}
 		}
 		free(pixels_long);
 		fit->bitpix = USHORT_IMG;
@@ -201,10 +208,10 @@ int readfits(const char *filename, fits *fit, char *realname) {
 		 * Indeed, it looks like that some FLOAT_IMG are in fact integers.
 		 * In order to read most pictures we test the maximum value to
 		 * know if the range is [0, 1] or not */
-		double maximum = gsl_stats_max(pixels_double, 1,
+		double m_double = gsl_stats_max(pixels_double, 1,
 				nbdata * fit->naxes[2]);
 		for (i = 0; i < nbdata * fit->naxes[2]; i++) {
-			if (maximum > 1.) {
+			if (m_double > 1.0) {
 				fit->data[i] = round_to_WORD(pixels_double[i]);
 			} else
 				fit->data[i] = round_to_WORD(
@@ -217,19 +224,19 @@ int readfits(const char *filename, fits *fit, char *realname) {
 		break;
 
 	default:
-		msg = siril_log_message("Unknown FITS image format.\n");
+		msg = siril_log_message(_("Unknown FITS image format.\n"));
 	}
 	if (msg) {
-		show_dialog(msg, "Error", "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		status = 0;
 		fits_close_file(fit->fptr, &status);
 		update_used_memory();
 		return -1;
 	}
 	if (status) {
-		msg = siril_log_message("Fitsio error reading data, file: %s.\n",
+		msg = siril_log_message(_("Fitsio error reading data, file: %s.\n"),
 				filename);
-		show_dialog(msg, "Error", "gtk-dialog-error");
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		report_fits_error(status);
 	}
 
@@ -242,8 +249,10 @@ int readfits(const char *filename, fits *fit, char *realname) {
 
 	status = 0;
 	fits_close_file(fit->fptr, &status);
-	siril_log_message("Reading FITS: file %s, %ld layer(s), %ux%u pixels\n",
-			filename, fit->naxes[2], fit->rx, fit->ry);
+	basename = g_path_get_basename(filename);
+	siril_log_message(_("Reading FITS: file %s, %ld layer(s), %ux%u pixels\n"),
+			basename, fit->naxes[2], fit->rx, fit->ry);
+	g_free(basename);
 	return 0;
 }
 
@@ -260,7 +269,7 @@ void read_fits_header(fits *fit) {
 	fits_read_key(fit->fptr, TINT, "BSCALE", &zero, NULL, &status);
 	if (!status && 1 != zero)
 		siril_log_message(
-				"Loaded FITS file has a BSCALE different than 1 (%d)\n", zero);
+				_("Loaded FITS file has a BSCALE different than 1 (%d)\n"), zero);
 	status = 0;
 	fits_read_key(fit->fptr, TINT, "BZERO", &zero, NULL, &status);
 
@@ -280,6 +289,14 @@ void read_fits_header(fits *fit) {
 	fits_read_key(fit->fptr, TSTRING, "INSTRUME", &(fit->instrume), NULL,
 			&status);
 
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "TELESCOP", &(fit->telescop), NULL,
+			&status);
+
+	status = 0;
+	fits_read_key(fit->fptr, TSTRING, "OBSERVER", &(fit->observer), NULL,
+			&status);
+
 	status = 0;
 	fits_read_key(fit->fptr, TSTRING, "DATE-OBS", &(fit->date_obs), NULL,
 			&status);
@@ -291,7 +308,7 @@ void read_fits_header(fits *fit) {
 	__tryToFindKeywords(fit->fptr, TDOUBLE, Focal, &fit->focal_length);
 	if (!sequence_is_loaded() || com.seq.current == 0)
 		fprintf(stdout,
-				"Read from FITS header: pix size %gx%g, binning %hix%hi, focal %g\n",
+				"Read from FITS header: pix size %gx%g, binning %ux%u, focal %g\n",
 				fit->pixel_size_x, fit->pixel_size_y, fit->binning_x,
 				fit->binning_y, fit->focal_length);
 
@@ -405,7 +422,7 @@ void report_fits_error(int status) {
 	if (status) {
 		char errmsg[FLEN_ERRMSG];
 		while (fits_read_errmsg(errmsg)) {
-			siril_log_message("FITS error: %s\n", errmsg);
+			siril_log_message(_("FITS error: %s\n"), errmsg);
 		}
 	}
 }
@@ -420,7 +437,7 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 	int zero = 0;
 
 	status = 0;
-	if (fits_open_file(&(fit->fptr), filename, READONLY, &status))
+	if (fits_open_diskfile(&(fit->fptr), filename, READONLY, &status))
 		report_fits_error(status);
 	if (status)
 		return status;
@@ -440,7 +457,7 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 		fit->naxes[2] = 1;	// see readfits for the explanation
 	if (layer > fit->naxes[2] - 1) {
 		siril_log_message(
-				"FITS read partial: there is no layer %d in the image %s\n",
+				_("FITS read partial: there is no layer %d in the image %s\n"),
 				layer + 1, filename);
 		status = 0;
 		fits_close_file(fit->fptr, &status);
@@ -459,7 +476,7 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 	nbdata = fit->rx * fit->ry;
 
 	if (fit->naxis == 3 && fit->naxes[2] != 3) {
-		siril_log_message("Unknown FITS image format (%ld axes).\n",
+		siril_log_message(_("Unknown FITS image format (%ld axes).\n"),
 				fit->naxes[2]);
 		status = 0;
 		fits_close_file(fit->fptr, &status);
@@ -468,7 +485,7 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 	if (fit->bitpix != SHORT_IMG && fit->bitpix != USHORT_IMG
 			&& fit->bitpix != BYTE_IMG) {
 		siril_log_message(
-				"Only Siril FITS images can be used with partial image reading.\n");
+				_("Only Siril FITS images can be used with partial image reading.\n"));
 		return -1;
 	}
 	fit->naxes[2] = 1;	// force to 1 layer
@@ -499,7 +516,7 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 	}
 	status = 0;
 	fits_close_file(fit->fptr, &status);
-	siril_log_message("Loaded partial FITS file %s\n", filename);
+	siril_log_message(_("Loaded partial FITS file %s\n"), filename);
 	return 0;
 }
 
@@ -515,13 +532,13 @@ int read_opened_fits_partial(sequence *seq, int layer, int index, WORD *buffer,
 	int zero = 0;
 
 	if (!seq || !seq->fptr || !seq->fptr[index]) {
-		siril_log_message("data initialization error in read fits partial\n");
+		printf("data initialization error in read fits partial\n");
 		return 1;
 	}
 	if (area->x < 0 || area->y < 0 || area->x >= seq->rx || area->y >= seq->ry
 			|| area->w <= 0 || area->h <= 0 || area->x + area->w > seq->rx
 			|| area->y + area->h > seq->ry) {
-		siril_log_message(
+		printf(
 				"partial read from FITS file has been requested outside image bounds or with invalid size\n");
 		return 1;
 	}
@@ -575,8 +592,7 @@ int savefits(const char *name, fits *f) {
 	f->naxes[1] = f->ry;
 
 	if (f->naxis == 3 && f->naxes[2] != 3) {
-		siril_log_message(
-				"Trying to save a FITS color file with more than 3 channels?");
+		printf("Trying to save a FITS color file with more than 3 channels?");
 		return 1;
 	}
 
@@ -589,7 +605,7 @@ int savefits(const char *name, fits *f) {
 	unlink(filename); /* Delete old file if it already exists */
 
 	status = 0;
-	if (fits_create_file(&(f->fptr), filename, &status)) { /* create new FITS file */
+	if (fits_create_diskfile(&(f->fptr), filename, &status)) { /* create new FITS file */
 		report_fits_error(status);
 		return 1;
 	}
@@ -636,9 +652,9 @@ int savefits(const char *name, fits *f) {
 	case DOUBLE_IMG:
 	default:
 		msg = siril_log_message(
-				"ERROR: trying to save a FITS image"
-				"with an unsupported format (%d).\n", f->bitpix);
-		show_dialog(msg, "Error", "gtk-dialog-error");
+				_("ERROR: trying to save a FITS image "
+				"with an unsupported format (%d).\n"), f->bitpix);
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		fits_close_file(f->fptr, &status);
 		return 1;
 	}
@@ -647,7 +663,7 @@ int savefits(const char *name, fits *f) {
 		save_fits_header(f);
 	fits_close_file(f->fptr, &status);
 	if (!status)
-		siril_log_message("Saving FITS: file %s, %ld layer(s), %ux%u pixels\n",
+		siril_log_message(_("Saving FITS: file %s, %ld layer(s), %ux%u pixels\n"),
 				filename, f->naxes[2], f->rx, f->ry);
 	return 0;
 }
@@ -691,7 +707,14 @@ void save_fits_header(fits *fit) {
 	if (fit->instrume[0] != '\0')
 		fits_update_key(fit->fptr, TSTRING, "INSTRUME", &(fit->instrume),
 				"instrument name", &status);
-
+	status = 0;
+	if (fit->telescop[0] != '\0')
+		fits_update_key(fit->fptr, TSTRING, "TELESCOP", &(fit->telescop),
+				"telescope used to acquire this image", &status);
+	status = 0;
+	if (fit->observer[0] != '\0')
+		fits_update_key(fit->fptr, TSTRING, "OBSERVER", &(fit->observer),
+				"observer name", &status);
 	status = 0;
 	int itmp;
 	char fit_date[40];
@@ -914,6 +937,33 @@ int copyfits(fits *from, fits *to, unsigned char oper, int layer) {
 	return 0;
 }
 
+/* copy non-mandatory keywords from 'from' to 'to' */
+int copy_header(fits *from, fits *to) {
+	to->pixel_size_x = from->pixel_size_x;
+	to->pixel_size_y = from->pixel_size_y;
+	to->binning_x = from->binning_x;
+	to->binning_y = from->binning_y;
+
+	strncpy(to->date_obs, from->date_obs, FLEN_VALUE);
+	strncpy(to->date, from->date, FLEN_VALUE);
+	strncpy(to->instrume, from->instrume, FLEN_VALUE);
+	strncpy(to->dft_type, from->dft_type, FLEN_VALUE);
+	strncpy(to->dft_ord, from->dft_ord, FLEN_VALUE);
+
+	to->focal_length = from->focal_length;
+	to->iso_speed = from->iso_speed;
+	to->exposure = from->exposure;
+	to->aperture = from->aperture;
+	to->ccd_temp = from->ccd_temp;
+	to->dft_norm[0] = from->dft_norm[0];
+	to->dft_norm[1] = from->dft_norm[1];
+	to->dft_norm[2] = from->dft_norm[2];
+	to->dft_rx = from->dft_rx;
+	to->dft_ry = from->dft_ry;
+
+	return 0;
+}
+
 int save1fits16(const char *filename, fits *fit, int layer) {
 	if (layer != RLAYER) {
 		int nbdata = fit->naxes[0] * fit->naxes[1];
