@@ -107,8 +107,8 @@ int read_single_image(const char* filename, fits *dest, char **realname_out) {
 	realname = malloc(strlen(filename) + 10);
 	retval = stat_file(filename, &imagetype, realname);
 	if (retval) {
-		char *msg = siril_log_message("Error opening image %s: file not found or not supported.\n", filename);
-		show_dialog(msg, "Error", "gtk-dialog-error");
+		char *msg = siril_log_message(_("Error opening image %s: file not found or not supported.\n"), filename);
+		show_dialog(msg, _("Error"), "gtk-dialog-error");
 		set_cursor_waiting(FALSE);
 		free(realname);
 		return 1;
@@ -122,7 +122,7 @@ int read_single_image(const char* filename, fits *dest, char **realname_out) {
 			debayer_if_needed(imagetype, dest);
 	}
 	if (retval != 0 && retval != 3)
-		siril_log_message("Opening %s failed.\n", realname);
+		siril_log_message(_("Opening %s failed.\n"), realname);
 	if (realname_out)
 		*realname_out = realname;
 	else free(realname);
@@ -146,20 +146,21 @@ int open_single_image(const char* filename) {
 	
 	/* A single sequence has been loaded */
 	if (retval == 3) {
-		siril_log_message("Sequence loaded: %s\n", com.seq.seqname);
 		return 0;
 	}
 	if (retval == 2) {
-		show_dialog("This file could not be openend because its extension is not supported.\n", "Error", "gtk-dialog-error");
+		show_dialog(_("This file could not be opened because its extension is not supported.\n"), _("Error"), "gtk-dialog-error");
 		return 1;
 	}
 	if (retval == 1) {
-		show_dialog("There was an error when opening this image. See the log for more information.", "Error", "gtk-dialog-error");
+		show_dialog(_("There was an error when opening this image. See the log for more information."), _("Error"), "gtk-dialog-error");
 		return 1;
 	}
 
 	if (sequence_is_loaded()) {
-		siril_log_message("Closing sequence %s\n", com.seq.seqname);
+		char *basename = g_path_get_basename(com.seq.seqname);
+		siril_log_message(_("Closing sequence %s\n"), basename);
+		g_free(basename);
 		clear_sequence_list();
 		free_sequence(&(com.seq), FALSE);
 		initialize_sequence(&com.seq, FALSE);
@@ -196,6 +197,10 @@ void open_single_image_from_gfit(char *realname) {
 	adjust_sellabel();
 
 	display_filename();	// display filename in gray window
+
+	/* update menus */
+	update_MenuItem();
+
 	redraw(com.cvport, REMAP_ALL);
 	update_used_memory();
 	show_main_gray_window();
@@ -217,7 +222,7 @@ int image_find_minmax(fits *fit, int force_minmax){
 	if (fit->maxi != 0 && !force_minmax) return 1;
 
 	/* search for min and max values in all layers */
-#pragma omp parallel for num_threads(com.max_thread) private(layer, i) schedule(dynamic,1)
+#pragma omp parallel for num_threads(com.max_thread) private(layer, i) schedule(dynamic,1) if(fit->naxes[2] > 1)
 	for (layer = 0; layer < fit->naxes[2]; ++layer) {
 		WORD *buf = fit->pdata[layer];
 		fit->max[layer] = 0;
