@@ -29,6 +29,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <assert.h>
+#include <locale.h>
 #if (defined(__APPLE__) && defined(__MACH__))
 #include <stdlib.h>
 #include <libproc.h>
@@ -36,6 +37,7 @@
 
 #include "core/siril.h"
 #include "core/proto.h"
+#include "core/initfile.h"
 #include "io/conversion.h"
 #include "gui/callbacks.h"
 #include "registration/registration.h"
@@ -82,8 +84,7 @@ int main(int argc, char *argv[]) {
 	int i;
 	extern char *optarg;
 	extern int opterr;
-	GString *homeStr;
-	gchar *homepath, *csspath, *siril_path;
+	gchar *siril_path;
 	char *cwd_orig = NULL;
 	struct sigaction sigIntHandler;
 #if (defined(__APPLE__) && defined(__MACH__))
@@ -93,28 +94,31 @@ int main(int argc, char *argv[]) {
 #endif
 	
 	setenv("LC_NUMERIC", "C", 1);		// avoid possible bugs using french separator ","
-	setenv("LANG", "C", 1);				// on french (or other) system, it avoids the mix between languages
 	opterr = 0;
 	memset(&com, 0, sizeof(struct cominf));	// needed?
 	com.initfile = NULL;
 
+	/* for translation */
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
+
 	/* Caught signals */
 	sigIntHandler.sa_handler = signal_handled;
 	sigemptyset(&sigIntHandler.sa_mask);
 	sigIntHandler.sa_flags = 0;
 	sigaction(SIGINT, &sigIntHandler, NULL);
 
-	while(1) {
+	while (1) {
 		signed char c = getopt(argc, argv, "i:hfv");
-		if (c=='?') {
-			for(i=1; i<argc; i++) {
-				if(argv[i][1] == '-') {
-					if(!strcmp(argv[i], "--version"))
-						c='v';
-					else if(!strcmp(argv[i], "--help"))
-						c='h';				
-					else if(!strcmp(argv[i], "--format"))
-						c='f';					
+		if (c == '?') {
+			for (i = 1; i < argc; i++) {
+				if (argv[i][1] == '-') {
+					if (!strcmp(argv[i], "--version"))
+						c = 'v';
+					else if (!strcmp(argv[i], "--help"))
+						c = 'h';
+					else if (!strcmp(argv[i], "--format"))
+						c = 'f';
 					else {
 						usage(argv[0]);
 						exit(EXIT_FAILURE);
@@ -123,25 +127,26 @@ int main(int argc, char *argv[]) {
 			}
 		}
 
-		if (c==-1) break;
-		switch(c) {
-			case 'i':
-				com.initfile = strdup(optarg);
-				break;
-			case 'v':
-				fprintf(stdout, "%s %s\n", PACKAGE, VERSION);
-				exit(EXIT_SUCCESS);
-				break;
-			case 'f':
-				list_format_available();
-				exit(EXIT_SUCCESS);
-				break;
-			default:
-				fprintf(stderr, "unknown command line parameter `%c'\n", c);
-				/* no break */
-			case 'h':
-				usage(argv[0]);
-				exit(EXIT_SUCCESS);
+		if (c == -1)
+			break;
+		switch (c) {
+		case 'i':
+			com.initfile = strdup(optarg);
+			break;
+		case 'v':
+			fprintf(stdout, "%s %s\n", PACKAGE, VERSION);
+			exit(EXIT_SUCCESS);
+			break;
+		case 'f':
+			list_format_available();
+			exit(EXIT_SUCCESS);
+			break;
+		default:
+			fprintf(stderr, _("unknown command line parameter '%c'\n"), argv[argc - 1][1]);
+			/* no break */
+		case 'h':
+			usage(argv[0]);
+			exit(EXIT_SUCCESS);
 		}
 	}
 
@@ -174,17 +179,17 @@ int main(int argc, char *argv[]) {
 		gchar *path = g_string_free (pathStr, FALSE);
 
 		if (gtk_builder_add_from_file (builder, path, &err)) {
-			fprintf(stdout, "Successfully loaded '%s%s'\n", siril_sources[i], GLADE_FILE);
+			fprintf(stdout, _("Successfully loaded '%s%s'\n"), siril_sources[i], GLADE_FILE);
 			g_free(path);
 			break;
 		}
-		fprintf (stderr, "Unable to read file: %s\n", err->message);
+		fprintf (stderr, _("Unable to read file: %s\n"), err->message);
 		g_free(path);
 		g_error_free(err);
 		i++;
 	} while (i < sizeof(siril_sources)/sizeof(char *));
 	if (i == sizeof(siril_sources) / sizeof(char *)) {
-		fprintf(stderr, "%s was not found or contains errors, cannot render GUI. Exiting.\n", GLADE_FILE);
+		fprintf(stderr, _("%s was not found or contains errors, cannot render GUI. Exiting.\n"), GLADE_FILE);
 		exit(EXIT_FAILURE);
 	}
 	siril_path = siril_sources[i];
@@ -204,7 +209,7 @@ int main(int argc, char *argv[]) {
 	gtk_text_buffer_create_tag (tbuf, "blue", "foreground", "#7a7af8", NULL);
 	gtk_text_buffer_create_tag (tbuf, "plum", "foreground", "#8e4585", NULL);
 	
-	siril_log_color_message("Welcome to %s v%s\n", "bold", PACKAGE, VERSION);
+	siril_log_color_message(_("Welcome to %s v%s\n"), "bold", PACKAGE, VERSION);
 
 	/* initialize converters (utilities used for different image types importing) */
 	initialize_converters();
@@ -258,6 +263,9 @@ int main(int argc, char *argv[]) {
 	/* initialize sequence-related stuff */
 	initialize_sequence(&com.seq, TRUE);
 	adjust_sellabel();
+	
+	/* load the css sheet for general style */
+	load_css_style_sheet (siril_path);
 
 	/* set default CWD and load init file */
 	com.wd = malloc(PATH_MAX + 1);// PATH_MAX may not be available on all systems
@@ -268,19 +276,15 @@ int main(int argc, char *argv[]) {
 		cwd_orig = strdup(com.wd);
 
 	if (checkinitfile()) {
-		siril_log_message("could not load or create settings file in ~/.siril, exiting.\n");
+		siril_log_message(_("Could not load or create settings file in ~/.siril, exiting.\n"));
 		exit(1);
 	}
-	
-	/* load the css sheet for general style */
-	homepath = getenv("HOME");
-	homeStr = g_string_new (homepath);
-	g_string_append(homeStr, "/.siril");
-	csspath = g_string_free (homeStr, FALSE);
 
-	load_css_style_sheet (siril_path, csspath);
+	/* initialize menu gui */
+	update_MenuItem();
 
-	g_free(csspath);
+	/* initialize preprocessing */
+	initialize_preprocessing();
 
 	/* initialize registration methods */
 	initialize_registration_methods();
@@ -311,15 +315,26 @@ int main(int argc, char *argv[]) {
 #endif
 	
 	/* Get CPU number and set the number of threads */
-	siril_log_message("Parallel processing %s: Using %d logical processor%s",
+	siril_log_message(_("Parallel processing %s: Using %d logical processor%s"),
 #ifdef _OPENMP
-			"enabled", com.max_thread = omp_get_num_procs(), "s.\n"
+			_("enabled"), com.max_thread = omp_get_num_procs(), "s.\n"
 #else
-			"disabled", com.max_thread = 1, ".\n"
+			_("disabled"), com.max_thread = 1, ".\n"
 #endif
 			);
 	update_spinCPU(com.max_thread);
 
+	if (com.have_dark_theme) {
+		/* Put dark icons */
+		printf("Loading dark theme...\n");
+		gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON(lookup_widget("rotate90_anticlock_button")), lookup_widget("rotate90-acw_dark"));
+		gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON(lookup_widget("rotate90_clock_button")), lookup_widget("rotate90-cw_dark"));
+		gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON(lookup_widget("mirrorx_button")), lookup_widget("image_mirrorx_dark"));
+		gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON(lookup_widget("mirrory_button")), lookup_widget("image_mirrory_dark"));
+		gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON(lookup_widget("histogram_button")), lookup_widget("image_histogram_dark"));
+		gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON(lookup_widget("seqlist_button")), lookup_widget("image_seqlist_dark"));
+	}
+
 	/* start Siril */
 	update_used_memory();
 
@@ -327,9 +342,9 @@ int main(int argc, char *argv[]) {
 		if (cwd_orig)
 			changedir(cwd_orig);
 		open_single_image(argv[optind]);
-		char *newpath = extract_path(argv[optind]);
+		gchar *newpath = g_path_get_dirname(argv[optind]);
 		changedir(newpath);
-		free(newpath);
+		g_free(newpath);
 	}
 	if (cwd_orig)
 		free(cwd_orig);
@@ -345,7 +360,7 @@ void initialize_scrollbars() {
 	char *vport_names[] = { "r", "g", "b", "rgb" };
 	char window_name[32];
 
-	for (i=0; i<sizeof(vport_names)/sizeof(char *); i++) {
+	for (i = 0; i < sizeof(vport_names) / sizeof(char *); i++) {
 		sprintf(window_name, "scrolledwindow%s", vport_names[i]);
 		GtkScrolledWindow *win = GTK_SCROLLED_WINDOW(gtk_builder_get_object(builder, window_name));
 		com.hadj[i] = gtk_scrolled_window_get_hadjustment(win);
