@@ -48,6 +48,23 @@ static WORD *fits_to_bgrbgr(fits *image) {
 	return bgrbgr;
 }
 
+int cvResizeGaussian_data8(uint8_t *dataIn, int rx, int ry, uint8_t *dataOut,
+		int toX, int toY, int chan, int interpolation) {
+	int mode = (chan == 1 ? CV_8UC1 : CV_8UC3);
+
+	Mat in(ry, rx, mode, dataIn);
+	Mat out(toY, toX, mode);
+
+	resize(in, out, out.size(), 0, 0, interpolation);
+
+	for (int i = 0; i < toX * toY * chan; i++)
+		dataOut[i] = (uint8_t) out.data[i];
+
+	in = Mat();
+	out = Mat();
+	return 0;
+}
+
 /* resizes image to the sizes toX * toY, and stores it back in image */
 int cvResizeGaussian(fits *image, int toX, int toY, int interpolation) {
 	assert(image->data);
@@ -182,13 +199,19 @@ int cvTransformImage(fits *image, TRANS trans, int interpolation) {
 	Mat in(image->ry, image->rx, CV_16UC3, bgrbgr);
 	Mat out(image->ry, image->rx, CV_16UC3);
 
-	Point2f pt(0, in.rows);
-	double angle = atan(trans.c / trans.b) * 180 / M_PI;
-	Mat r = getRotationMatrix2D(pt, -angle, 1.0);
-	warpAffine(in, out, r, in.size(), interpolation);
+	double angle = -atan2(trans.c, trans.b);
+	double s = sqrt(trans.b * trans.b + trans.c * trans.c);
 
-	r = (Mat_<double>(2, 3) << 1, 0, trans.a, 0, 1, -trans.d);
-	warpAffine(out, out, r, in.size(), interpolation);
+    // http://en.wikipedia.org/wiki/Transformation_matrix#Affine_transformations
+	Mat transform = Mat::eye(2, 3, CV_64FC1);
+	transform.at<double>(0, 0) = s * cos(angle);
+	transform.at<double>(0, 1) = -s * sin(angle);
+	transform.at<double>(1, 0) = s * sin(angle);
+	transform.at<double>(1, 1) = s * cos(angle);
+	transform.at<double>(0, 2) = trans.a;	// shift dx
+	transform.at<double>(1, 2) = trans.d;	// shift dy
+
+	warpAffine(in, out, transform, in.size(), interpolation);
 
 	Mat channel[3];
 	split(out, channel);
@@ -217,7 +240,7 @@ int cvTransformImage(fits *image, TRANS trans, int interpolation) {
 	delete[] bgrbgr;
 	in = Mat();
 	out = Mat();
-	r = Mat();
+	transform = Mat();
 	return 0;
 }
 
