@@ -13,6 +13,8 @@ extern "C" {
 #include "registration/matching/misc.h"
 
 int cvResizeGaussian(fits *, int, int, int);
+int cvResizeGaussian_data8(uint8_t *dataIn, int rx, int ry, uint8_t *dataOut,
+		int toX, int toY, int chan, int interpolation);
 int cvRotateImage(fits *, double, int, int);
 int cvTransformImage(fits *, TRANS, int);
 int cvUnsharpFilter(fits*, double, double);
